@@ -1,6 +1,5 @@
-import satkit as sk
 import numpy as np
-
+import satkit as sk
 
 def read_sp3file(fname, satnum=20):
     """
@@ -32,6 +31,6 @@ def read_sp3file(fname, satnum=20):
     match = f"PG{satnum:02d}"
     satlines = list(filter(lambda x: x[0:4] == match, lines))
     dates = np.fromiter(line2date(datelines), sk.time)
-    pitrf = np.stack(np.fromiter(line2pos(satlines), list), axis=0) * 1.0e3
+    pitrf = np.stack(np.fromiter(line2pos(satlines), list), axis=0) * 1.0e3  # type: ignore
 
     return (pitrf, dates)
