@@ -149,6 +149,28 @@ class TestTime:
         assert minute == 0
         assert sec == 0
 
+    def test_day_of_year(self):
+        t = sk.time(2021, 1, 1)
+        assert t.day_of_year() == 1
+
+        t = sk.time(2021, 12, 31)
+        assert t.day_of_year() == 365
+
+        t = sk.time(2020, 12, 31)
+        assert t.day_of_year() == 366
+
+        t = sk.time(2100, 12, 31)
+        assert t.day_of_year() == 365
+
+        t = sk.time(2400, 12, 31)
+        assert t.day_of_year() == 366
+
+        t = sk.time(2024, 2, 29)
+        assert t.day_of_year() == 60
+
+        t = sk.time(2025, 8, 16)
+        assert t.day_of_year() == 228
+
 
 class TestKepler:
     def test_kepler_from_pv(self):
@@ -443,6 +465,42 @@ class TestMoon:
         ref_pos = np.array([-134240.626e3, -311571.590e3, -126693.785e3])
         assert p == pytest.approx(ref_pos)
 
+    def test_moon_phase(self):
+        # Checked against https://www.timeanddate.com/moon/phases/
+        t = sk.time(2025, 11, 12, 0, 46, 0)
+        phasename = sk.moon.phase_name(t)
+        assert phasename == sk.moon.moonphase.LastQuarter
+        illumination = sk.moon.illumination(t)
+        assert illumination == pytest.approx(0.52, rel=1e-2)
+
+    def test_moon_phase_name(self):
+        """
+        Test moon phase name function
+        against known moon phases in early 2024
+
+        phases compared against results from https://www.moongiant.com/
+        """
+
+        # New moon - Jan 11 2024
+        t_new = sk.time(2024, 1, 11, 17, 8, 0)
+        phase_new = sk.moon.phase_name(t_new)
+        assert phase_new == sk.moon.moonphase.NewMoon
+
+        # First quarter - Jan 18 2024
+        t_first = sk.time(2024, 1, 18, 12, 0, 0)
+        phase_first = sk.moon.phase_name(t_first)
+        assert phase_first == sk.moon.moonphase.FirstQuarter
+
+        # Full moon - Jan 25 2024
+        t_full = sk.time(2024, 1, 25, 4, 54, 0)
+        phase_full = sk.moon.phase_name(t_full)
+        assert phase_full == sk.moon.moonphase.FullMoon
+
+        # Last quarter - Feb 2 2024
+        t_last = sk.time(2024, 2, 2, 2, 0, 0)
+        phase_last = sk.moon.phase_name(t_last)
+        assert phase_last == sk.moon.moonphase.LastQuarter
+
 
 class TestSun:
     def test_sunpos_mod(self):
@@ -549,6 +607,21 @@ class TestQuaternion:
         dcm = q.as_rotation_matrix()
         assert dcm @ xhat == pytest.approx(yhat, 1.0e-10)
 
+    def test_construction(self):
+        """
+        Test construction of quaternions from scalars
+        """
+        s = 1 / m.sqrt(2.0)
+        q = sk.quaternion(s, s, 0, 0)
+        assert q.axis == pytest.approx(np.array([1.0, 0.0, 0.0]), 1.0e-10)
+        assert q.angle == pytest.approx(m.pi / 2, 1.0e-10)
+        q = sk.quaternion(s, 0, s, 0)
+        assert q.axis == pytest.approx(np.array([0.0, 1.0, 0.0]), 1.0e-10)
+        assert q.angle == pytest.approx(m.pi / 2, 1.0e-10)
+        q = sk.quaternion(s, 0, 0, s)
+        assert q.axis == pytest.approx(np.array([0.0, 0.0, 1.0]), 1.0e-10)
+        assert q.angle == pytest.approx(m.pi / 2, 1.0e-10)
+
     def test_quaternion2euler(self):
         """
         Test conversion of quaternion to Euler angles
@@ -709,6 +782,62 @@ class TestSatState:
         assert np.array([0.0, 0.0, 1.0]) == pytest.approx(rz, abs=1e-10)
 
 
+class TestTLE:
+    def test_tle_setting(self):
+        """
+        Test setting TLE parameters
+        """
+        line1 = "1 25544U 98067A   21275.59097222  .00016717  00000-0  10270-3 0  9003"
+        line2 = "2 25544  51.6432 351.4697 0007417 130.5364 329.6482 15.48915330299357"
+        tle = sk.TLE.from_lines([line1, line2])
+        if isinstance(tle, list):
+            tle = tle[0]
+        assert tle.inclination == pytest.approx(51.6432, rel=1e-7)
+        assert tle.raan == pytest.approx(351.4697, rel=1e-7)
+        assert tle.eccen == pytest.approx(0.0007417, rel=1e-7)
+        assert tle.arg_of_perigee == pytest.approx(130.5364, rel=1e-7)
+        assert tle.mean_anomaly == pytest.approx(329.6482, rel=1e-7)
+        assert tle.mean_motion == pytest.approx(15.48915330, rel=1e-7)
+        assert tle.bstar == pytest.approx(0.00010270, rel=1e-4)
+        assert abs((tle.epoch - sk.time(2021, 10, 2, 14, 10, 59.0)).seconds) < 1
+
+        tle.raan = 50.0
+        assert tle.raan == pytest.approx(50.0, rel=1e-7)
+        tle.eccen = 0.1
+        assert tle.eccen == pytest.approx(0.1, rel=1e-7)
+        tle.arg_of_perigee = 40.0
+        assert tle.arg_of_perigee == pytest.approx(40.0, rel=1e-7)
+        tle.mean_anomaly = 300.0
+        assert tle.mean_anomaly == pytest.approx(300.0, rel=1e-7)
+        tle.mean_motion = 14.0
+        assert tle.mean_motion == pytest.approx(14.0, rel=1e-7)
+        tle.bstar = 0.0002
+        assert tle.bstar == pytest.approx(0.0002, rel=1e-4)
+
+
+class TestTLEFitting:
+    def test_tle_fit(self):
+        """
+        Test fitting of TLE From high-precision states
+        """
+        altitude = 400e3
+        r0 = sk.consts.earth_radius + altitude
+        v0 = m.sqrt(sk.consts.mu_earth / r0)
+        inc = 97 * m.pi / 180
+        state0 = np.array([r0, 0, 0, 0, v0 * m.cos(inc), v0 * m.sin(inc)])
+
+        sp = sk.satproperties_static(cdaoverm=2.0 * 10 / 3500)
+        tm = sk.time(2016, 5, 16, 12, 0, 0)
+        res = sk.propagate(
+            state0, tm, stop=tm + sk.duration.from_days(1), satproperties=sp
+        )
+        time_arr = [tm + sk.duration(seconds=x * 10) for x in range(8640)]
+        state_arr = [res.interp(t) for t in time_arr]
+        epoch = time_arr[0]
+
+        _tle, _result = sk.TLE.fit_from_states(state_arr, time_arr, epoch)  # type: ignore
+
+
 class TestSGP4:
     def test_sgp4_multiple(self):
         """
@@ -740,6 +869,27 @@ class TestSGP4:
         assert p2 == pytest.approx(np.squeeze(p[2, :, :]))
         assert v2 == pytest.approx(np.squeeze(v[2, :, :]))
 
+    def test_to_lines(self):
+        """
+        Test converting TLE to lines
+        """
+
+        lines = [
+            "STARLINK-3118",
+            "1 49140U 21082L   24030.39663557  .00000076  00000-0  14180-4 0  9995",
+            "2 49140  70.0008  34.1139 0002663 260.3521  99.7337 14.98327656131736",
+        ]
+        tle = sk.TLE.from_lines(lines)
+
+        if isinstance(tle, list):
+            tle = tle[0]
+
+        lines2 = tle.to_2line()
+        assert lines[1:] == lines2
+
+        lines2 = tle.to_3line()
+        assert lines == lines2
+
     def test_sgp4_vallado(self):
         """
         SGP4 Test Vectors from vallado
