@@ -14,11 +14,15 @@ mod rkv98_table;
 mod rkv98_nointerp;
 mod rkv98_nointerp_table;
 
+mod rkv98_efficient;
+mod rkv98_efficient_table;
+
 pub use rkf45::RKF45;
 pub use rkts54::RKTS54;
 pub use rkv65::RKV65;
 pub use rkv87::RKV87;
 pub use rkv98::RKV98;
+pub use rkv98_efficient::RKV98Efficient;
 pub use rkv98_nointerp::RKV98NoInterp;
 
 // Re-export RKAdaptive trait for use by the adpative solvers
