@@ -20,12 +20,14 @@ pub mod rk_explicit;
 mod types;
 
 // NAlgebera bindings for ODE state
-mod nalgebra;
+mod nalgebra_bindings;
 
 pub use rk_adaptive::RKAdaptive;
 pub use rk_adaptive_settings::RKAdaptiveSettings;
 
 pub mod solvers {
+    #[allow(unused)]
+    pub use super::adaptive_solvers::RKV98Efficient;
     pub use super::adaptive_solvers::RKV98NoInterp;
     #[allow(unused)]
     pub use super::adaptive_solvers::RKF45;
