@@ -10,6 +10,8 @@ use crate::{Instant, TimeScale, Weekday};
 
 use super::pyduration::PyDuration;
 
+use anyhow::{bail, Result};
+
 use numpy as np;
 
 /// Specify time scale used to represent or convert between the "satkit.time"
@@ -179,9 +181,11 @@ impl<'py> IntoPyObject<'py> for crate::Instant {
     }
 }
 
-impl<'py> FromPyObject<'py> for Instant {
-    fn extract_bound(ob: &Bound<'py, PyAny>) -> PyResult<Self> {
-        let obj = PyInstant::extract_bound(ob)?;
+impl<'a, 'py> FromPyObject<'a, 'py> for Instant {
+    type Error = pyo3::pyclass::PyClassGuardError<'a, 'py>;
+
+    fn extract(ob: Borrowed<'a, 'py, PyAny>) -> Result<Self, Self::Error> {
+        let obj = PyInstant::extract(ob)?;
         Ok(obj.0)
     }
 }
@@ -210,7 +214,7 @@ impl PyInstant {
     ///     satkit.time: Time object representing input date and time, or if no arguments, the current date and time
     #[new]
     #[pyo3(signature=(*py_args))]
-    fn py_new(py_args: &Bound<'_, PyTuple>) -> PyResult<Self> {
+    fn py_new(py_args: &Bound<'_, PyTuple>) -> Result<Self> {
         if py_args.is_empty() {
             Ok(Self(Instant::now()))
         } else if py_args.len() == 3 {
@@ -228,23 +232,21 @@ impl PyInstant {
 
             Ok(Self(Instant::from_datetime(
                 year, month, day, hour, min, sec,
-            )))
+            )?))
         } else if py_args.len() == 1 {
             let item = py_args.get_item(0)?;
             let s = item.extract::<&str>()?;
 
             // Input is a string, first try rfc3339 format
             match Instant::from_rfc3339(s) {
-                Ok(v) => return Ok(Self(v)),
+                Ok(v) => Ok(Self(v)),
                 Err(_) => {
                     // Now try multiple formats
-                    return Self::from_string(s);
+                    Self::from_string(s)
                 }
             }
         } else {
-            Err(pyo3::exceptions::PyTypeError::new_err(
-                "Must pass in year, month, day or year, month, day, hour, min, sec",
-            ))
+            bail!("Must pass in year, month, day or year, month, day, hour, min, sec");
         }
     }
 
@@ -260,15 +262,8 @@ impl PyInstant {
     ///   ValueError: If input string cannot be parsed
     ///
     #[staticmethod]
-    fn from_string(s: &str) -> PyResult<Self> {
-        Instant::from_string(s).map_or_else(
-            |_| {
-                Err(pyo3::exceptions::PyValueError::new_err(
-                    "Could not parse time string",
-                ))
-            },
-            |v| Ok(Self(v)),
-        )
+    fn from_string(s: &str) -> Result<Self> {
+        Instant::from_string(s).map(Self)
     }
 
     /// Create satkit.time object from string with given format
@@ -295,15 +290,8 @@ impl PyInstant {
     /// %b: Month as locale’s abbreviated name
     /// %B: Month as locale’s full name
     #[staticmethod]
-    fn strptime(s: &str, fmt: &str) -> PyResult<Self> {
-        Instant::strptime(s, fmt).map_or_else(
-            |_| {
-                Err(pyo3::exceptions::PyValueError::new_err(
-                    "Could not parse time string",
-                ))
-            },
-            |v| Ok(Self(v)),
-        )
+    fn strptime(s: &str, fmt: &str) -> Result<Self> {
+        Instant::strptime(s, fmt).map(Self)
     }
 
     /// Format time object as string
@@ -331,15 +319,10 @@ impl PyInstant {
     /// %B: Month as locale’s full name
     /// %w: Weekday as a decimal number, where 0 is Sunday and 6 is Saturday
     ///
-    fn strftime(&self, fmt: &str) -> PyResult<String> {
-        self.0.strftime(fmt).map_or_else(
-            |_| {
-                Err(pyo3::exceptions::PyValueError::new_err(
-                    "Could not format time string",
-                ))
-            },
-            Ok,
-        )
+    fn strftime(&self, fmt: &str) -> Result<String> {
+        self.0
+            .strftime(fmt)
+            .map_err(|e| anyhow::anyhow!("Could not format time string: {}", e))
     }
 
     /// Create satkit.time object from RFC3339 string
@@ -399,8 +382,8 @@ impl PyInstant {
     /// Returns:
     ///     satkit.time: Time object representing current time
     #[staticmethod]
-    fn now() -> PyResult<Self> {
-        Ok(Self(Instant::now()))
+    fn now() -> Self {
+        Self(Instant::now())
     }
 
     /// Return time object representing input date
@@ -413,8 +396,8 @@ impl PyInstant {
     /// Returns:
     ///     satkit.time: Time object representing instant of input date
     #[staticmethod]
-    fn from_date(year: i32, month: i32, day: i32) -> PyResult<Self> {
-        Ok(Self(Instant::from_date(year, month, day)))
+    fn from_date(year: i32, month: i32, day: i32) -> Result<Self> {
+        Ok(Self(Instant::from_date(year, month, day)?))
     }
 
     /// Return time object representing input modified Julian date and time scale
@@ -474,6 +457,16 @@ impl PyInstant {
         self.0.as_datetime()
     }
 
+    /// Return the 1-based Gregorian day of the year (1 = January 1, 365 = December 31)
+    /// Leap-year aware
+    ///
+    /// Returns:
+    ///     int : The 1-based day of the year
+    ///
+    fn day_of_year(&self) -> u32 {
+        self.0.day_of_year()
+    }
+
     /// Create satkit.time representing input UTC Gegorian date and time
     ///
     /// Args:
@@ -496,10 +489,8 @@ impl PyInstant {
         hour: i32,
         min: i32,
         sec: f64,
-    ) -> PyResult<Self> {
-        Ok(Self(Instant::from_datetime(
-            year, month, day, hour, min, sec,
-        )))
+    ) -> Result<Self> {
+        Instant::from_datetime(year, month, day, hour, min, sec).map(Self)
     }
 
     /// Convert from Python datetime object
@@ -529,8 +520,8 @@ impl PyInstant {
     ///     datetime.datetime:  datetime object matching the input satkit.time
     ///
     #[pyo3(signature = (utc=true))]
-    fn datetime(&self, utc: bool) -> PyResult<PyObject> {
-        pyo3::Python::with_gil(|py| -> PyResult<PyObject> {
+    fn datetime(&self, utc: bool) -> PyResult<Py<PyAny>> {
+        pyo3::Python::attach(|py| -> PyResult<Py<PyAny>> {
             let timestamp: f64 = self.as_unixtime();
             let tz = match utc {
                 false => None,
@@ -591,11 +582,11 @@ impl PyInstant {
     ///
     /// Returns:
     ///     satkit.time|numpy.ndarray: New time object or numpy array of time objects representing input time plus input duration(s)
-    fn __add__(&self, other: &Bound<'_, PyAny>) -> PyResult<PyObject> {
+    fn __add__(&self, other: &Bound<'_, PyAny>) -> PyResult<Py<PyAny>> {
         // Numpy array of floats
         if other.is_instance_of::<np::PyArray1<f64>>() {
             let parr = other.extract::<np::PyReadonlyArray1<f64>>()?;
-            pyo3::Python::with_gil(|py| -> PyResult<PyObject> {
+            pyo3::Python::attach(|py| -> PyResult<Py<PyAny>> {
                 let objarr = parr
                     .as_array()
                     .map(|x| {
@@ -604,7 +595,7 @@ impl PyInstant {
                             .unwrap()
                     })
                     .into_iter();
-                let parr = np::PyArray1::<PyObject>::from_iter(py, objarr);
+                let parr = np::PyArray1::<Py<PyAny>>::from_iter(py, objarr);
                 parr.into_py_any(py)
             })
         }
@@ -619,25 +610,25 @@ impl PyInstant {
                             ))
                         },
                         |v| {
-                            pyo3::Python::with_gil(|py| -> PyResult<PyObject> {
+                            pyo3::Python::attach(|py| -> PyResult<Py<PyAny>> {
                                 let objarr = v.into_iter().map(|x| {
                                     let pyobj = Self(self.0 + x.0);
                                     pyobj.into_py_any(py).unwrap()
                                 });
 
-                                let parr = np::PyArray1::<PyObject>::from_iter(py, objarr);
+                                let parr = np::PyArray1::<Py<PyAny>>::from_iter(py, objarr);
                                 parr.into_py_any(py)
                             })
                         },
                     )
                 },
                 |v| {
-                    pyo3::Python::with_gil(|py| -> PyResult<PyObject> {
+                    pyo3::Python::attach(|py| -> PyResult<Py<PyAny>> {
                         let objarr = v.iter().map(|x| {
                             let pyobj = Self(self.0 + crate::Duration::from_days(*x));
                             pyobj.into_py_any(py).unwrap()
                         });
-                        let parr = np::PyArray1::<PyObject>::from_iter(py, objarr);
+                        let parr = np::PyArray1::<Py<PyAny>>::from_iter(py, objarr);
                         parr.into_py_any(py)
                     })
                 },
@@ -666,15 +657,15 @@ impl PyInstant {
     ///
     /// Returns:
     ///     satkit.time|numpy.ndarray|satkit.duration: New time object or numpy array of time objects representing input time minus input duration(s), or duration object representing difference between two time objects
-    fn __sub__(&self, other: &Bound<'_, PyAny>) -> PyResult<PyObject> {
+    fn __sub__(&self, other: &Bound<'_, PyAny>) -> PyResult<Py<PyAny>> {
         // Numpy array of floats
         if other.is_instance_of::<np::PyArray1<f64>>() {
             let parr: np::PyReadonlyArray1<f64> = other.extract().unwrap();
-            let objarr = parr.as_array().into_iter().map(|x| -> PyObject {
+            let objarr = parr.as_array().into_iter().map(|x| -> Py<PyAny> {
                 let obj = Self(self.0 - crate::Duration::from_days(*x));
                 obj.into_py_any(other.py()).unwrap()
             });
-            let parr = np::PyArray1::<PyObject>::from_iter(other.py(), objarr);
+            let parr = np::PyArray1::<Py<PyAny>>::from_iter(other.py(), objarr);
             parr.into_py_any(other.py())
         }
         // list of floats
@@ -693,7 +684,7 @@ impl PyInstant {
                                 pyobj.into_py_any(other.py()).unwrap()
                             });
 
-                            let parr = np::PyArray1::<PyObject>::from_iter(other.py(), objarr);
+                            let parr = np::PyArray1::<Py<PyAny>>::from_iter(other.py(), objarr);
                             parr.into_py_any(other.py())
                         },
                     )
@@ -703,7 +694,7 @@ impl PyInstant {
                         let pyobj = Self(self.0 - crate::Duration::from_days(x));
                         pyobj.into_py_any(other.py()).unwrap()
                     });
-                    let parr = np::PyArray1::<PyObject>::from_iter(other.py(), objarr);
+                    let parr = np::PyArray1::<Py<PyAny>>::from_iter(other.py(), objarr);
                     parr.into_py_any(other.py())
                 },
             )
@@ -713,7 +704,7 @@ impl PyInstant {
             || other.is_instance_of::<pyo3::types::PyInt>()
         {
             let dt: f64 = other.extract::<f64>().unwrap();
-            pyo3::Python::with_gil(|py| -> PyResult<PyObject> {
+            pyo3::Python::attach(|py| -> PyResult<Py<PyAny>> {
                 Self(self.0 - crate::Duration::from_days(dt)).into_py_any(py)
             })
         } else if other.is_instance_of::<PyDuration>() {
@@ -798,7 +789,7 @@ impl PyInstant {
         Ok(())
     }
 
-    fn __getstate__(&mut self, py: Python) -> PyResult<PyObject> {
+    fn __getstate__(&mut self, py: Python) -> PyResult<Py<PyAny>> {
         Ok(PyBytes::new(py, &i64::to_le_bytes(self.0.raw)).into())
     }
 }
@@ -830,14 +821,14 @@ impl ToTimeVec for &Bound<'_, PyAny> {
             Ok(vec![tm.0])
         } else if self.is_instance_of::<PyDateTime>() {
             let dt: Py<PyDateTime> = self.extract().unwrap();
-            pyo3::Python::with_gil(|py| Ok(vec![datetime_to_instant(dt.bind(py)).unwrap()]))
+            pyo3::Python::attach(|py| Ok(vec![datetime_to_instant(dt.bind(py)).unwrap()]))
         }
         // List case
         else if self.is_instance_of::<pyo3::types::PyList>() {
             match self.extract::<Vec<PyInstant>>() {
                 Ok(v) => Ok(v.iter().map(|x| x.0).collect::<Vec<_>>()),
                 Err(_e) => match self.extract::<Vec<Py<PyDateTime>>>() {
-                    Ok(v) => pyo3::Python::with_gil(|py| {
+                    Ok(v) => pyo3::Python::attach(|py| {
                         Ok(v.iter()
                             .map(|x| datetime_to_instant(x.bind(py)).unwrap())
                             .collect::<Vec<_>>())
@@ -849,9 +840,9 @@ impl ToTimeVec for &Bound<'_, PyAny> {
             }
         }
         // numpy array case
-        else if self.is_instance_of::<numpy::PyArray1<PyObject>>() {
-            match self.extract::<numpy::PyReadonlyArray1<PyObject>>() {
-                Ok(v) => pyo3::Python::with_gil(|py| -> PyResult<Vec<Instant>> {
+        else if self.is_instance_of::<numpy::PyArray1<Py<PyAny>>>() {
+            match self.extract::<numpy::PyReadonlyArray1<Py<PyAny>>>() {
+                Ok(v) => pyo3::Python::attach(|py| -> PyResult<Vec<Instant>> {
                     // Extract times from numpya array of objects
                     let tmarray: Result<Vec<Instant>, _> = v
                         .as_array()
@@ -859,7 +850,7 @@ impl ToTimeVec for &Bound<'_, PyAny> {
                         .map(|p| -> Result<Instant, _> {
                             p.extract::<PyInstant>(py).map_or_else(|_| p.extract::<Py<PyDateTime>>(py).map_or_else(|_| Err(pyo3::exceptions::PyTypeError::new_err(
                                         "Input numpy array must contain satkit.time elements or datetime.datetime elements".to_string()
-                                    )), |v3| pyo3::Python::with_gil(|py| {
+                                    )), |v3| pyo3::Python::attach(|py| {
                                         Ok(datetime_to_instant(v3.bind(py)).unwrap())
                                     })), |v2| Ok(v2.0))
                         })
