@@ -22,14 +22,15 @@ use crate::Instant;
 ///
 #[pyfunction]
 #[pyo3(signature=(alt_km, **option_kwds))]
-pub fn nrlmsise00(alt_km: f64, option_kwds: Option<&Bound<'_, PyDict>>) -> PyResult<(f64, f64)> {
+pub fn nrlmsise00(
+    alt_km: f64,
+    option_kwds: Option<&Bound<'_, PyDict>>,
+) -> anyhow::Result<(f64, f64)> {
     let mut lat: Option<f64> = None;
     let mut lon: Option<f64> = None;
     let mut tm: Option<Instant> = None;
     let mut use_spaceweather: bool = true;
-    if option_kwds.is_some() {
-        let kwds = option_kwds.unwrap();
-
+    if let Some(kwds) = option_kwds {
         if let Some(kw) = kwds.get_item("latitude_deg")? {
             lat = Some(kw.extract::<f64>()?);
         }
@@ -37,7 +38,11 @@ pub fn nrlmsise00(alt_km: f64, option_kwds: Option<&Bound<'_, PyDict>>) -> PyRes
             lon = Some(v.extract::<f64>()?);
         }
         if let Some(v) = kwds.get_item("time")? {
-            tm = Some(v.extract::<PyInstant>()?.0);
+            tm = Some(
+                v.extract::<PyInstant>()
+                    .map_err(|_e| anyhow::anyhow!("Failed to extract time"))?
+                    .0,
+            );
         }
         if let Some(v) = kwds.get_item("use_spaceweather")? {
             use_spaceweather = v.extract::<bool>()?;
